Struct ExtTransientSeatV1
pub struct ExtTransientSeatV1 { /* private fields */ }wayland and Linux only.Expand description
transient seat handle
When the transient seat handle is destroyed, the seat itself will also be destroyed.
See also the Request enum for this interface.
Implementations
impl ExtTransientSeatV1
impl ExtTransientSeatV1
pub fn ready(&self, global_name: u32)
pub fn ready(&self, global_name: u32)
transient seat is ready
This event advertises the global name for the wl_seat to be used with wl_registry_bind.
It is sent exactly once, immediately after the transient seat is created and the new “wl_seat” global is advertised, if and only if the creation of the transient seat was allowed.
pub fn denied(&self)
pub fn denied(&self)
transient seat creation denied
The event informs the client that the compositor denied its request to create a transient seat.
It is sent exactly once, immediately after the transient seat object is created, if and only if the creation of the transient seat was denied.
After receiving this event, the client should destroy the object.